# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.seqq_service_batch_start_searches_request import SeqqServiceBatchStartSearchesRequest

class TestSeqqServiceBatchStartSearchesRequest(unittest.TestCase):
    """SeqqServiceBatchStartSearchesRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SeqqServiceBatchStartSearchesRequest:
        """Test SeqqServiceBatchStartSearchesRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SeqqServiceBatchStartSearchesRequest`
        """
        model = SeqqServiceBatchStartSearchesRequest()
        if include_optional:
            return SeqqServiceBatchStartSearchesRequest(
                requests = [
                    seqq.models.v1alpha_start_search_request.v1alphaStartSearchRequest(
                        collection = '', 
                        search = seqq.models.apiv1alpha_search.apiv1alphaSearch(
                            name = '', 
                            query = '', 
                            code = 'CODE_UNSPECIFIED', 
                            prefix = '', 
                            query_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            query_duration = '', 
                            hits = [
                                seqq.models.v1alpha_hit.v1alphaHit(
                                    saccver = '', 
                                    pident = 1.337, 
                                    length = '', 
                                    mismatch = '', 
                                    gapopen = '', 
                                    qstart = '', 
                                    qend = '', 
                                    sstart = '', 
                                    send = '', 
                                    evalue = 1.337, 
                                    bitscore = 1.337, )
                                ], 
                            state = 'STATE_UNSPECIFIED', 
                            error = seqq.models.rpc_status.rpcStatus(
                                message = '', 
                                details = [
                                    {
                                        'key' : None
                                        }
                                    ], ), 
                            strategy = seqq.models.v1alpha_strategy.v1alphaStrategy(
                                blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(
                                    task = 'TASK_UNSPECIFIED', ), 
                                blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                                blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                                tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(), 
                                tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx(), ), ), )
                    ]
            )
        else:
            return SeqqServiceBatchStartSearchesRequest(
                requests = [
                    seqq.models.v1alpha_start_search_request.v1alphaStartSearchRequest(
                        collection = '', 
                        search = seqq.models.apiv1alpha_search.apiv1alphaSearch(
                            name = '', 
                            query = '', 
                            code = 'CODE_UNSPECIFIED', 
                            prefix = '', 
                            query_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            query_duration = '', 
                            hits = [
                                seqq.models.v1alpha_hit.v1alphaHit(
                                    saccver = '', 
                                    pident = 1.337, 
                                    length = '', 
                                    mismatch = '', 
                                    gapopen = '', 
                                    qstart = '', 
                                    qend = '', 
                                    sstart = '', 
                                    send = '', 
                                    evalue = 1.337, 
                                    bitscore = 1.337, )
                                ], 
                            state = 'STATE_UNSPECIFIED', 
                            error = seqq.models.rpc_status.rpcStatus(
                                message = '', 
                                details = [
                                    {
                                        'key' : None
                                        }
                                    ], ), 
                            strategy = seqq.models.v1alpha_strategy.v1alphaStrategy(
                                blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(
                                    task = 'TASK_UNSPECIFIED', ), 
                                blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                                blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(), 
                                tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(), 
                                tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx(), ), ), )
                    ],
        )
        """

    def testSeqqServiceBatchStartSearchesRequest(self):
        """Test SeqqServiceBatchStartSearchesRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
