# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BlastnTask(str, Enum):
    """
     - TASK_UNSPECIFIED: TASK_UNSPECIFIED is the default value.  - MEGABLAST: MEGABLAST is a search optimized for highly similar sequences.  - DC_MEGABLAST: DC_MEGABLAST is typically used for inter-species comparisons.  - BLASTN: BLASTN is a standard search.  - BLASTN_SHORT: BLASTN_SHORT is a search optimized for short queries.
    """

    """
    allowed enum values
    """
    TASK_UNSPECIFIED = 'TASK_UNSPECIFIED'
    MEGABLAST = 'MEGABLAST'
    DC_MEGABLAST = 'DC_MEGABLAST'
    BLASTN = 'BLASTN'
    BLASTN_SHORT = 'BLASTN_SHORT'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BlastnTask from a JSON string"""
        return cls(json.loads(json_str))


