# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_strategy import V1alphaStrategy

class TestV1alphaStrategy(unittest.TestCase):
    """V1alphaStrategy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaStrategy:
        """Test V1alphaStrategy
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaStrategy`
        """
        model = V1alphaStrategy()
        if include_optional:
            return V1alphaStrategy(
                blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(
                    task = 'TASK_UNSPECIFIED', ),
                blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(),
                blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(),
                tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(),
                tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx()
            )
        else:
            return V1alphaStrategy(
        )
        """

    def testV1alphaStrategy(self):
        """Test V1alphaStrategy"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
